%description: calculate normal load and driving force required
%inputs:
    % Vehicle parameters, Operating conditions, vehicle axle and mass ranges
%outputs:
    % normal load (per axle), driving force required


function[NormalLoad, DriveForce]=calculateNormalResistLoad(Vehicle, OpCond, TestRange)

VehicleMass_Range=TestRange.VehicleMass; %kg
AxleNumber_Range=TestRange.Axle; 


slope=OpCond(1);
speed=OpCond(2);
accel=OpCond(3); 


NormalLoad=cell(length(VehicleMass_Range),length(AxleNumber_Range));
DriveForce=cell(length(VehicleMass_Range),length(AxleNumber_Range));

%% calculate air drag and slope vehicle resistances
AirDragResistance=0.5*Vehicle.air_density*Vehicle.Cd*Vehicle.Area*speed^2;
SlopeResistance=VehicleMass_Range*9.81*sin(slope);

%% calculate normal load for each axle at every time step
%pitch moments
pitchmoment1=VehicleMass_Range*9.81*sin(slope);
pitchmoment2=VehicleMass_Range*9.81*cos(slope);
%acceleration moment
accelmoment=VehicleMass_Range*accel;
%drag moment
dragmoment=AirDragResistance;


DrivingForceRequired=VehicleMass_Range*accel+AirDragResistance+SlopeResistance;

for Axle_index=1:length(AxleNumber_Range)
    axle_number=AxleNumber_Range(Axle_index);
    
    switch axle_number
        case 2
            %front axle load
            axleload(:,1)=(1/Vehicle.Lww).*(-pitchmoment1*(Vehicle.r+Vehicle.h_wcg)+pitchmoment2*(Vehicle.Lww/axle_number)-(accelmoment+dragmoment)*(Vehicle.r+Vehicle.h_wcg));
            %rear axle load
            axleload(:,2)=(1/Vehicle.Lww).*(pitchmoment1*(Vehicle.r+Vehicle.h_wcg)+pitchmoment2*(Vehicle.Lww/axle_number)+(accelmoment+dragmoment)*(Vehicle.r+Vehicle.h_wcg));            
            %wheel load
            NormalLoad(:,Axle_index)=num2cell(axleload./2, 2);
            
            
        case 3
            %front axle load
            axleload(:,1)=(1/Vehicle.Lww).*(-pitchmoment1*(Vehicle.r+Vehicle.h_wcg)+pitchmoment2*(Vehicle.Lww/axle_number)-(accelmoment+dragmoment)*(Vehicle.r+Vehicle.h_wcg));
            %rear axle load
            axleload(:,3)=(1/Vehicle.Lww).*(pitchmoment1*(Vehicle.r+Vehicle.h_wcg)+pitchmoment2*(Vehicle.Lww/axle_number)+(accelmoment+dragmoment)*(Vehicle.r+Vehicle.h_wcg));            
            %middle axle load
            axleload(:,2)=0.5.*(axleload(:,1)+axleload(:,3));
            %wheel load
            NormalLoad(:,Axle_index)=num2cell(axleload./2, 2);
            
            
        case 4
            %front axle load
            axleload(:,1)=(1/(20*Vehicle.Lww)).*(-18*pitchmoment1*(Vehicle.r+Vehicle.h_wcg)+5*pitchmoment2*(Vehicle.Lww)-18*(accelmoment+dragmoment)*(Vehicle.r+Vehicle.h_wcg));
            %rear axle load
            axleload(:,4)=(1/(20*Vehicle.Lww)).*(18*pitchmoment1*(Vehicle.r+Vehicle.h_wcg)+5*pitchmoment2*(Vehicle.Lww)+18*(accelmoment+dragmoment)*(Vehicle.r+Vehicle.h_wcg));            
            %middle axle load
            axleload(:,2)=(2/3).*axleload(:,1)+(1/3).*axleload(:,4);
            axleload(:,3)=(1/3).*axleload(:,1)+(2/3).*axleload(:,4);
            %wheel load
            NormalLoad(:,Axle_index)=num2cell(axleload./2, 2);
            

    end
    
    DriveForce(:,Axle_index)=num2cell(DrivingForceRequired);


end
