

%% Inputs
%% Wheel
Wheel.r=0.12; %wheel radius [m]
Wheel.b=0.04; %wheel width [m]

%load wheel file stored in Wheel_Database (created earlier using createWheelTables)
addpath('Wheel_Database');
load(['wheel_r_',num2str(Wheel.r*1000),'_b_',num2str(Wheel.b*1000)])


%% Vehicle
Vehicle.air_density=1.202; %air density [kg/m^3]
Vehicle.Cd=0.5; %air drag coefficient
Vehicle.width=0.2; %vehicle width [m]
Vehicle.Lww=0.5; %length from front wheel to rear wheel [m]
Vehicle.r=0.1; %wheel radius [m]
Vehicle.h_wcg=0.05; %vehicle cg height above wheel center [m]
Vehicle.Area=0.9*(Vehicle.r+Vehicle.h_wcg)*Vehicle.width; %frontal area for air drag calculation [m^2]


%% Operating Conditions

Requirement.Payload=10; %kg
Requirement.Endurance=10; %km
%available terrain choices (automatically loaded in GUI, for given wheel table):
%   [LooseAirDrySand
%    MediumSoil
%    ClayedSoil]
Requirement.Soil=[1;2]; %index of available terrain choices

            %slope[rad]     %speed[m/s]     %acceleration[m^2/s]    %include range[0 or 1]
TempOpCond=[5*(pi/180)      5               0.25                     0;...
            0               10              0                        1];


%% Axle and Mass Range
TestRange.VehicleMass=(1:1:100)'; %range of vehicle mass to consider [kg]
TestRange.Axle=[2,3]; %number of axles to consider [2,3,4]


%% Battery
batteryIndex = 1; %index selects battery type (currently only one battery stored)
Battery = populateBatteryDatabase(batteryIndex); %select battery


%% Motor
motorIndex = 1; %index selects motor type (currently only one motor stored)
motorQuantity = 2; %number of electric motors
Motor = selectAndScaleMotor(motorIndex,1); %select and scale motor (initially scale with factor 1)
%store inputs for later validation (loaded/unloaded check)
Motor.number=motorQuantity;
Motor.NumberCheck=motorQuantity;
Motor.Type=motorIndex;


%% Transmission
%fixed gear transmission between electric motor and wheels
Transmission.ratio = 10;


%% Begin Design
%% Normal Load & Driving Force (accel+slope+air resistance forces) Calculation

%make complete operating conditions
Num_OpCond=size(TempOpCond,1);

OpCond=zeros(Num_OpCond*length(Requirement.Soil),5);
    %*recommend power<=>slope spec, energy<=>zero slope spec
for soil_index=1:length(Requirement.Soil)
    %slope              speed                       accel                  soil                               power=0,energy=1,both=2  
OpCond(1+(Num_OpCond*(soil_index-1)):Num_OpCond*soil_index,:)=...
    [TempOpCond(:,1:3), ones(Num_OpCond,1).*Requirement.Soil(soil_index), TempOpCond(:,4)];
        
end

Design=func_NormalLoads(Vehicle,OpCond,TestRange);


%% Wheel Force Calculation
[Design]=func_WheelForces(Design,Requirement,Vehicle,Wheel,TestRange,OpCond);


%% Motor Scaling
[Design]=func_MotorScaling(Design,Requirement,OpCond,TestRange,Transmission,Motor,Battery);


%% Payload Performance, Payload Feasibility
[Design]=func_PayloadCapability(Design,TestRange,Requirement);


%% Output
%% Plot
%Label operating conditions:
OpCondLabel = {'Slope Traversal' 'Cruising Range'};
for index=1:2
    plot_number=index;
    figure(plot_number); clf;
    [LegendText, LegendColors] = func_PlotFigures(plot_number,Wheel,TestRange,Design,Requirement,OpCond,Num_OpCond,OpCondLabel);
    tempLegend = ['\fontsize{8} {'];
    for jj = 1:length(LegendText)
        switch LegendColors{jj}
            case 'r'
                tempColor = 'red';
            case 'g'
                tempColor = 'green';
            case 'm'
                tempColor = 'magenta';
            case 'y'
                tempColor = 'yellow';
            case 'b'
                tempColor = 'blue';
            case 'k'
                tempColor = 'black';
        end
        tempLegend = [tempLegend,'\color{',tempColor,'} ',LegendText{jj},' '];
        if jj==length(LegendText)
            tempLegend = [tempLegend,'}'];
        end
    end
	legend(tempLegend,'Location','South');
%     legend(['\fontsize{8} black {\color{magenta}magenta \color[rgb]{0 .5 .5}teal \color{r}r} black again']) 
end
