%description: determine motor properties for many operating conditions

function[Design] = func_MotorScaling(Design,Requirement,OpCond,TestRange,Transmission,Motor,Battery)

%reorganize operating conditions
[Soil_temp,Speed_temp,Accel_temp,PowerEnergyBoth_temp,OpCond_PowerIndex,OpCond_EnergyIndex]=func_TempCond(OpCond,TestRange);

for Axle_index=1:size(Design,2)
    
    %arrange wheel torque and speed in one matrix
    temp_TrqSpd = [vertcat(Design(:,Axle_index).WheelTorqueRequired), vertcat(Design(:,Axle_index).WheelSpeed)];
    
    %find the optimal motor scaling for given transmission 
        %*minimize mass of motor+battery for payload considerations
    [Output] = calculateMassOptimalMotorScaling(temp_TrqSpd,Speed_temp,PowerEnergyBoth_temp,Requirement,Transmission,Motor,Battery);
    
    
    
    %Reorder output, assign to Design
    for row_index=1:size(Design,1)
        
        temp_begin=row_index*size(OpCond,1)-size(OpCond,1)+1;
        temp_end=temp_begin+size(OpCond,1)-1;
        
        %motor feasibility
        Design(row_index,Axle_index).MotorFeasibility=min(Output.Feasibility(temp_begin:temp_end,1));   %unit: [-]
        
        %motor scaling for all operating conditions
        Design(row_index,Axle_index).MotorMassScaling=Output.Scale(temp_begin:temp_end,1);    %unit: [-]
        
        %motor/battery mass for all operating conditions
        Design(row_index,Axle_index).MotorMassAll=Output.MotorMass(temp_begin:temp_end,1);      %unit: [kg]
        Design(row_index,Axle_index).BatteryMassAll=Output.BatteryMass(temp_begin:temp_end,1);  %unit: [kg]
        
        %motor current/voltage/power/efficiency required for all operating conditions
        Design(row_index,Axle_index).MotorCurrent=Output.Current_req(temp_begin:temp_end,1);    %unit: [A]
        Design(row_index,Axle_index).MotorVoltage=Output.Voltage_req(temp_begin:temp_end,1);    %unit: [V]
        Design(row_index,Axle_index).MotorPower=Output.Power_req(temp_begin:temp_end,1);    %unit: [W]
        Design(row_index,Axle_index).MotorEfficiency=Output.Efficiency(temp_begin:temp_end,1);  %unit: [-]
        
        %determine maximum motor scaling required for all conditions
            %if one condition is nan - scaling is nan
        %determine maximum motor/battery mass required for all conditions
        switch Design(row_index,Axle_index).MotorFeasibility
            case 1
                Design(row_index,Axle_index).MotorMinMassScaling=max(Output.Scale(temp_begin:temp_end,1));        %unit: [-]
                Design(row_index,Axle_index).MotorMass=max(Output.MotorMass(temp_begin:temp_end,1));      %unit: [kg]
                Design(row_index,Axle_index).BatteryMass=max(Output.BatteryMass(temp_begin:temp_end,1));  %unit: [kg]
            case 0
                Design(row_index,Axle_index).MotorMinMassScaling=nan;
                Design(row_index,Axle_index).MotorMass=nan;      
                Design(row_index,Axle_index).BatteryMass=nan; 
        end
        
    end
        
   
end