%description: calculate the normal load for each wheel and driving force required over a range of operating conditions
%inputs:
	% Vehicle parameters, operating conditions, vehicle mass and axle number ranges
%outpus:
	% normal load for each axle, driving force for vehicle


function[Design]=func_NormalLoads(Vehicle,OpCond,TestRange)


%% Begin Design

%Design Space, rows=Vehicle Mass, columns=Axle Number
Design(length(TestRange.VehicleMass),length(TestRange.Axle))=struct('NormalLoad',[]);

%% Normal Load & Driving Force (accel+slope+air resistance forces) Calculation

for OpCond_index=1:size(OpCond,1)
    [Normal_temp,Dforce_temp]=calculateNormalResistLoad(Vehicle,OpCond(OpCond_index,1:3),TestRange);

    for row_index=1:size(Design,1)
        for column_index=1:size(Design,2)
            %assign normal load (wheel - not axle -  value, left/right same)
                %for each wheel (columns)
                %for each operating condition (rows)
            Design(row_index,column_index).NormalLoad(OpCond_index,:)=Normal_temp{row_index,column_index};
            
            %assign driving force (Mass*Accel + Slope_Resist + Air_Resist)
                %*** total force for all wheels (left/right, all axles)
            Design(row_index,column_index).DrivingForce(OpCond_index,:)=Dforce_temp{row_index,column_index};
        end
    end
    
end
