%description: adjust motor and battery scaling to accound for payload requirement

function[Design]=func_PayloadCapability(Design,TestRange,Requirement)


%in order to be able to meet the payload spec, the motor and battery must
%be sized to handle the additional load
    %use the motor/battery mass for the vehicle+payload mass to be safe


%first determine the index shift caused by the payload capacity:
    %i.e. if shift=5 then instead of index=1 (vehicle), index=1+shift (vehicle+payload)
temp_lowestmass=TestRange.VehicleMass(1);
temp_lowestwithpayload=temp_lowestmass+Requirement.Payload;

payload_indexshift=-1+nanmodified_interp1(TestRange.VehicleMass,1:length(TestRange.VehicleMass),temp_lowestwithpayload);

    
for axle_index=1:size(Design,2)
    %make a list of the motor/battery mass based on vehicle mass
    temp_motormass(:,1)=vertcat(Design(:,axle_index).MotorMass);
    temp_batterymass(:,1)=vertcat(Design(:,axle_index).BatteryMass);
    
    %interpolate to determine the motor/battery mass for payload mass
    temp_newmotormass(:,1)=nanmodified_interp1(temp_motormass,(1:length(temp_motormass))+payload_indexshift);
    temp_newbatterymass(:,1)=nanmodified_interp1(temp_batterymass,(1:length(temp_batterymass))+payload_indexshift);
    
    
    %make a list of the wheel mass
    temp_wheelmass(:,1)=vertcat(Design(:,axle_index).WheelMass);
    
    
    %determine flex mass (vehicle mass minus mass of wheels,motor,battery)
    temp_flexmass=TestRange.VehicleMass-(temp_wheelmass+temp_newmotormass+temp_newbatterymass);
    
    %values which are negative are infeasible (no room for vehicle frame)
    temp_flexmass(temp_flexmass<0)=nan;
    
    temp_feasible=~isnan(temp_flexmass);
    
    for row_index=1:size(Design,1)
        %assign to design
        Design(row_index,axle_index).PayloadMotorMass=temp_newmotormass(row_index);
        Design(row_index,axle_index).PayloadBatteryMass=temp_newbatterymass(row_index);
        Design(row_index,axle_index).PayloadFeasibility=temp_feasible(row_index);
    end
    
end