%description: plot mass feasibility ranges for given vehicle parameters and operating conditions

function[LegendText, LegendColors] = func_PlotFigures(plot_number,Wheel,TestRange,Design,Requirement,OpCond,Num_OpCond,OpCondLabel)

LineColor={'-r' '--r' '-.r';'-b' '--b' '-.b';'-g' '--g' '-.g';'-m' '--m' '-.m'};

TerrainColor={'r' 'b' 'g' 'm'};


for plot_index=1:length(plot_number)

figure_number=plot_number(plot_index);

switch figure_number
    
    case 1
    
%Terramechanics Feasibility
switch length(plot_number)>1
    case 1
        figure(figure_number); hold off
end

Terrain_Feasibility=nan(length(TestRange.VehicleMass)*size(OpCond,1),length(TestRange.Axle));
%extract terrain feasibility data (for all operating conditions)
for column_index=1:length(TestRange.Axle)
    Terrain_Feasibility(:,column_index)=vertcat(Design(:,column_index).TerrainFeasibilityAll);
end

%find mass range that is feasible (for each axle number, terrain, opcond)
terrain_step=2;
axle_step=5;


%determine location of x_tick points:
axleplot_width=terrain_step*length(Requirement.Soil);
axleplot_midpoint=round(terrain_step*length(Requirement.Soil)/2);


for opcond_index=1:Num_OpCond
    subplot(Num_OpCond,1,opcond_index);
    
    bar_begin=0;
    AxleTick=zeros(1,length(TestRange.Axle));
    
    for axle_index=1:length(TestRange.Axle)
    
        for terrain_index=1:length(Requirement.Soil)
            %select terrain_feasibility which has the same op cond, axle, terrain
            temp_massFeasibility=Terrain_Feasibility(terrain_index*Num_OpCond-Num_OpCond+opcond_index:length(Requirement.Soil)*Num_OpCond:end,axle_index);
            
            %find minimum/maximum feasible mass (first find index value)
            temp_minmassindex=find(temp_massFeasibility,1,'first');
            temp_maxmassindex=find(temp_massFeasibility,1,'last');
            
            temp_minmass=TestRange.VehicleMass(temp_minmassindex);
            temp_maxmass=TestRange.VehicleMass(temp_maxmassindex);
            
            bar_end=bar_begin+terrain_step;
            
            mass_check=~isempty(temp_minmass) & ~isempty(temp_maxmass);
            
            switch mass_check
                case 1 
                    choose_color=TerrainColor{terrain_index};
                case 0
                    temp_minmass=0;
                    temp_maxmass=1;
                    choose_color='w';
            end
            
            %plot points based on axle number, terrain
            modified_shadedplot([bar_begin,bar_end],temp_minmass.*ones(1,2),temp_maxmass.*ones(1,2),choose_color,choose_color); hold all
            
            bar_begin=bar_end;

        end
        bar_begin=bar_begin+axle_step;
        AxleTick(axle_index)=(axle_index-1)*(axleplot_width+axle_step) + axleplot_midpoint; 
        AxleLabel{1,axle_index}=[num2str(TestRange.Axle(axle_index)),' axles'];
    end
    grid off
    set(gca,'XLim',[0 bar_end]);
    set(gca,'XTick',AxleTick);
    set(gca,'XTickLabel',AxleLabel(1,:));
    ylabel('Vehicle Mass [kg]');
    title(['Terrain Feasibility, ',OpCondLabel{opcond_index}]);
end

%build legend
LegendText = cell(length(Requirement.Soil),1);
LegendColors = cell(length(Requirement.Soil),1);

LegendText(:,1) = Wheel.TerrainList(Requirement.Soil)';
LegendColors(:,1) = TerrainColor(1:length(Requirement.Soil))';






    case 2

%Vehicle Mass (Frame) using Vehicle+Payload Mass for Component Spec
switch length(plot_number)>1
    case 1
        figure(figure_number); hold off
end

temp_maxmass=0;
for axle_index=1:length(TestRange.Axle)
    temp_subplot=subplot(1,length(TestRange.Axle),axle_index);
    
    temp_wheelmass=vertcat(Design(:,axle_index).WheelMass);
    temp_motormass=vertcat(Design(:,axle_index).PayloadMotorMass);
    temp_batterymass=vertcat(Design(:,axle_index).PayloadBatteryMass);
    
    %find low/high feasible vehicle mass
    temp_lowmassindex=find(~isnan(temp_batterymass),1,'first');
    temp_highmassindex=find(~isnan(temp_batterymass),1,'last');
    temp_plotrange=temp_lowmassindex:temp_highmassindex;
    
    num_points=length(temp_plotrange);
    
    switch num_points
        
        case 1 %only one point mass is feasible
%             temp_plotrange = [temp_plotrange temp_plotrange]; %repeat one point
            
            graph_type='point';
            
        case 0 %no points are feasible
            graph_type='error';
            
        otherwise %more than one point is feasible
            graph_type='shaded';
            
    end
    
    switch graph_type
        case 'error'
            
            temp_textbox=annotation('textbox');
%             temp_position=get(temp_subplot,'Position');
%             set(temp_textbox,'String','All Mass Values are Infeasible',...
%                 'FitBoxToText','on','HorizontalAlignment','center',...
%                 'VerticalAlignment','middle','LineStyle','none','Position',temp_position)
            set(temp_textbox,'String','All Mass Values are Infeasible',...
                'FitBoxToText','on','HorizontalAlignment','center',...
                'VerticalAlignment','middle','LineStyle','none','Position',[0 0 1 1]) 
           
            
            
        case 'shaded'
    
    plot_vehiclemass=TestRange.VehicleMass(temp_plotrange)';
    plot_zero=0.*temp_wheelmass(temp_plotrange)';
    plot_wheelmass=temp_wheelmass(temp_plotrange)';
    plot_motormass=temp_wheelmass(temp_plotrange)'+temp_motormass(temp_plotrange)';
    plot_batterymass=temp_wheelmass(temp_plotrange)'+temp_motormass(temp_plotrange)'+temp_batterymass(temp_plotrange)';
    
    
    %mass of wheels
    modified_shadedplot(plot_vehiclemass, plot_zero, plot_wheelmass, TerrainColor{1}, TerrainColor{1}); hold on
    %add mass of motor
    modified_shadedplot(plot_vehiclemass, plot_wheelmass, plot_motormass, TerrainColor{2}, TerrainColor{2}); hold on
    %add mass of battery
    modified_shadedplot(plot_vehiclemass, plot_motormass, plot_batterymass, TerrainColor{3}, TerrainColor{3}); hold on

    %add leftover region/overweight region
        %first find overweight region:
        temp_difference=plot_vehiclemass - plot_batterymass;
        temp_overweight=min(temp_difference,temp_difference.*0);
        %second find leftover region (for vehicle frame mass)
        temp_leftover=max(temp_difference,0.*temp_difference);
    modified_shadedplot(plot_vehiclemass, plot_vehiclemass, plot_batterymass+temp_overweight,'m','m'); hold on
    modified_shadedplot(plot_vehiclemass, plot_vehiclemass, plot_batterymass+temp_leftover,'y','y'); hold on
    
    
    %add line for vehicle mass (linear)
    plot(plot_vehiclemass,plot_vehiclemass,'--k','LineWidth',2); hold on
    
    
        case 'point'
    plot_vehiclemass=[TestRange.VehicleMass(temp_plotrange) TestRange.VehicleMass(temp_plotrange)];
    plot_zero=0.*temp_wheelmass(temp_plotrange)';
    plot_wheelmass=temp_wheelmass(temp_plotrange)';
    plot_motormass=temp_wheelmass(temp_plotrange)'+temp_motormass(temp_plotrange)';
    plot_batterymass=temp_wheelmass(temp_plotrange)'+temp_motormass(temp_plotrange)'+temp_batterymass(temp_plotrange)';
    
    
    %mass of wheels
    plot(plot_vehiclemass, [plot_zero, plot_wheelmass], ['-',TerrainColor{1}],'LineWidth',2); hold on
    %add mass of motor
    plot(plot_vehiclemass, [plot_wheelmass, plot_motormass], ['-',TerrainColor{2}],'LineWidth',2); hold on
    %add mass of battery
    plot(plot_vehiclemass, [plot_motormass, plot_batterymass], ['-',TerrainColor{3}],'LineWidth',2); hold on

    %add leftover region/overweight region
        %first find overweight region:
        temp_difference=plot_vehiclemass - plot_batterymass;
        temp_overweight=min(temp_difference,temp_difference.*0);temp_overweight=temp_overweight(1);
        %sedond find leftover region (for vehicle frame mass)
        temp_leftover=max(temp_difference,0.*temp_difference);temp_leftover=temp_leftover(1);
    plot(plot_vehiclemass, [plot_vehiclemass(1), plot_batterymass+temp_overweight],'m','LineWidth',2); hold on
    plot(plot_vehiclemass, [plot_vehiclemass(1), plot_batterymass+temp_leftover],'y','LineWidth',2); hold on
    
    
    %add line for vehicle mass (linear)
    plot(plot_vehiclemass,plot_vehiclemass,'*k','LineWidth',2); hold on     
            
    end
    
    %add labels, find maximum y-axis mass, resize x-axis
    if strcmp(graph_type,'point') || strcmp(graph_type,'shaded')
    title([num2str(TestRange.Axle(axle_index)),' axles']);
    ylabel('component mass [kg]');
    xlabel('vehicle mass [kg]');
    temp_maxmass=max([temp_maxmass,max(plot_vehiclemass),plot_batterymass]);
    xlim([min(plot_vehiclemass) max(plot_vehiclemass)+eps]);
    end
    
end


%resize to same y-axis limit
switch strcmp(graph_type,'point') || strcmp(graph_type,'shaded')
    case 1
        for axle_index=1:length(TestRange.Axle)
            temp_subplot=subplot(1,length(TestRange.Axle),axle_index);
            ylim([0 temp_maxmass]);
        end
end


%build legend
               %wheel, motor, battery, chassis, overrun
temp_legend = {'wheel' 'motor' 'battery' 'remaining' 'overrun'};
temp_color = [TerrainColor(1,1:3) 'm' 'y'];

LegendText = cell(length(temp_legend),1);
LegendColors = cell(length(temp_legend),1);

LegendText(:,1) = temp_legend';
LegendColors(:,1) = temp_color';



    otherwise

end %switch

end %figures
