%description: determine feasibility and capability of vehicle design for given operating condition
%inputs:
    % normal load, driving force required, Vehicle parameters, Wheel parameters, Operating conditions, ...
%outputs:
    % terrain feasibility, wheel slip, drawbar pull, ...


function[Design] = func_WheelForces(Design,Requirement,Vehicle,Wheel,TestRange,OpCond)

%reorganize operating conditions
[Soil_temp,Speed_temp,Accel_temp,PowerEnergyBoth_temp,OpCond_PowerIndex,OpCond_EnergyIndex]=func_TempCond(OpCond,TestRange);



for Axle_index=1:size(Design,2)
    
    %Normal load for all operating conditions and vehicle mass (one matrix)
    N_temp=vertcat(Design(:,Axle_index).NormalLoad);
    Dforce_temp=vertcat(Design(:,Axle_index).DrivingForce);

    
    [Output]=calculateWheelForce(Vehicle,Wheel,N_temp,Dforce_temp,Soil_temp,Speed_temp,Accel_temp,Requirement);

    
    %Reorder output, assign to Design
    for row_index=1:size(Design,1)
        
        temp_begin=row_index*size(OpCond,1)-size(OpCond,1)+1;
        temp_end=temp_begin+size(OpCond,1)-1;
        
        %able to meet wheel force requirement (for all op conditions)
        Design(row_index,Axle_index).TerrainFeasibility=min(Output.WheelFeasibility(temp_begin:temp_end,1));    %unit: [-]
        Design(row_index,Axle_index).TerrainFeasibilityAll=Output.WheelFeasibility(temp_begin:temp_end,1);    %unit: [-]
        
        %wheel slip and speed
        Design(row_index,Axle_index).WheelSlip=Output.WheelSlip(temp_begin:temp_end,1);         %unit: [-]
        Design(row_index,Axle_index).WheelSpeed=Output.WheelSpeed(temp_begin:temp_end,1);       %unit: [m/s]
        
        %max drawbar pull, torque in, power in/out
        Design(row_index,Axle_index).WheelMaxDrawbarPull=Output.MaxDrawbarPull(temp_begin:temp_end,1);      %unit: [N]
        Design(row_index,Axle_index).WheelTorqueRequired=Output.TorqueRequired(temp_begin:temp_end,1);      %unit: [N-m]
        Design(row_index,Axle_index).WheelPowerRequired=Output.PowerRequired(temp_begin:temp_end,1);        %unit: [W]
        Design(row_index,Axle_index).WheelPowerOutput=Output.PowerOutput(temp_begin:temp_end,1);            %unit: [W]
        
        %determine maximum power required for all conditions
            %if one condition is nan - max power is nan
        %determine maximum power required for cruising/endurance condition
        temp_PowerRequired=Output.PowerRequired(temp_begin:temp_end,1);
        
        switch Design(row_index,Axle_index).TerrainFeasibility
            
            case 1
                Design(row_index,Axle_index).WheelMaxPower=max(temp_PowerRequired);            %unit: [W]                
                Design(row_index,Axle_index).WheelCruisePower=max(temp_PowerRequired(OpCond_EnergyIndex));     %unit: [W]
            case 0
                Design(row_index,Axle_index).WheelMaxPower=nan;
                Design(row_index,Axle_index).WheelCruisePower=nan;
        end
        
        %determine wheel mass (all wheels, including left/right)
        Design(row_index,Axle_index).WheelMass=TestRange.Axle(Axle_index)*2*Wheel.mass;     %unit: [kg]
  
    end

end