%description: select motor type and scale properties 

function [Motor] = selectAndScaleMotor(motor_select,motor_scale)

MotorDatabase(:,:) = {'Maxon EC Motor, 4pole, 45mm square, brushless, 300 Watt';...
                     };

switch nargin
    case 0
        Motor = MotorDatabase(:,1);
               
    otherwise

%% select motor
switch motor_select
    case 1 %%% Motor: Maxon EC Motor, 4pole, 45mm square, brushless, 300 Watt

%%% Values at nominal voltage
V_nom_orig = 48; %nominal voltage [V]
N_nl_orig = 4010*((2*pi)/60); %no load speed [rad/s]
I_nl_orig = 0.193; %no load current [A]
N_nom_orig = 3580*((2*pi)/60); %nominal speed [rad/s]
T_nom_orig = 0.635; %nominal torque (max continuous torque) [Nm]
I_nom_orig = 5.61; %nominal current (max continuous current) [A]
T_stall_orig = 7.69; %stall torque [Nm]
I_start_orig = 67.6; %starting current [A]
Eff_max_orig = 0.9; %maximum efficiency

%%% Characteristics
R_motor_orig = 0.710; %terminal resistance phase to phase [Ohm]
L_motor_orig = 0.677e-3; %terminal inductance phase to phase [H]
Kt_motor_orig = 0.114; %torque constant [Nm/A]
Kv_motor_orig = 84.0*((2*pi)/60); %speed constant [(rad/s)/V]
SpeedTorqueGrad_motor_orig = 0.524*((2*pi)/60)*1000; %speed/torque gradient [(rad/s)/Nm]
Tconstant_mech_orig = 2.02e-3; %mechanical time constant [s]
J_motor_orig = 368/(100^2*1000); %rotor inertia [kg/m^2]

%%% Thermal data *not included in this model

%%% Other Specifications
Mass_motor_orig = 1.13; %motor mass [kg]

end


%% Scale *Hofmann paper method
V_nom_scaled = V_nom_orig; % voltage remains the same
I_nl_scaled = motor_scale*I_nl_orig;
T_nom_scaled = T_nom_orig*motor_scale^3;
I_nom_scaled = motor_scale*I_nom_orig;
T_stall_scaled = T_stall_orig*motor_scale^3;

R_motor_scaled = R_motor_orig/motor_scale;
L_motor_scaled = L_motor_orig/motor_scale; %unsure how to determine (Henry using Ohm-sec)
Kt_motor_scaled = Kt_motor_orig*motor_scale^2;
Kv_motor_scaled = Kv_motor_orig/motor_scale^2;
J_motor_scaled = J_motor_orig*motor_scale^5; %not easily determined

Mass_motor_scaled = Mass_motor_orig*motor_scale^3;


%% Output
Motor.V_nom = V_nom_scaled;
Motor.I_nl = I_nl_scaled;
Motor.T_nom = T_nom_scaled;
Motor.I_nom = I_nom_scaled;
Motor.T_stall = T_stall_scaled;
Motor.P_nom = I_nom_scaled*V_nom_scaled;

Motor.R = R_motor_scaled;
Motor.L = L_motor_scaled;
Motor.Kt = Kt_motor_scaled;
Motor.Kv = Kv_motor_scaled;
Motor.J = J_motor_scaled;

Motor.Mass = Mass_motor_scaled;

end