function [Terrain] = terraintype(terrain_type)
% References:
% J.Y.Wong. Terramechanics and Off-Road Vehicle Engineering. (2nd Edition). 2010.
% Kr=1 is required when no Kr value given
    switch terrain_type
        case 'LooseAirDrySand' %%% p.427
            %density:[N/m^3]   cohesion:[Pa]       phi:[rad]       n:[-]    kc:[N/m^(n+1)]     kphi:[N/m^(n+2)]      K/Kt/Kw:[m]    Kr:       ShearType:
            gamma=14.55e3;        c=0e3;            phi=0.478;      n=0.91;  kc=-0.66e3;        kphi=754.13e3;         Kt=0.005;     Kr=1;     ShearType=1;
            
            %p.386 (rear unknown)
            %front contact angle constants          %rear contact angle constants
            a0=0.18;              a1=0.32;          b0=0;           b1=0;      
            
            %p.88
            %repetative loading parameters:
            %k0:[N/m^3]           Au:[N/m^4]
            k0=0;                 Au=503e6;

        case 'MediumSoil' %%% p.420
            gamma=15.0e3;         c=8.62e3;         phi=0.393;      n=0.8;   kc=29.76e3;        kphi=2083e3;           Kt=0.0254;    Kr=1;     ShearType=1;

            %Wong 1967 pt1, p.3 for compact sand (rear unknown)
            %front contact angle constants          %rear contact angle constants
            a0=0.43;              a1=0.32;          b0=0;           b1=0;      
            
            %p.420
            %repetative loading parameters:
            %k0:[N/m^3]           Au:[N/m^4]
            k0=0;                 Au=192.4e6;
            
        case 'ClayedSoil' %%% p.420
            gamma=12.74e3;        c=7.58e3;         phi=0.244;      n=0.6;   kc=30.08e3;        kphi=499.7e3;          Kt=0.0254;    Kr=1;     ShearType=1;

            %Wong 1967 pt1, p.3 for compact sand (rear unknown)
            %front contact angle constants          %rear contact angle constants
            a0=0.43;              a1=0.32;          b0=0;           b1=0;      
            
            %p.420
            %repetative loading parameters:
            %k0:[N/m^3]           Au:[N/m^4]
            k0=0;                 Au=63.106e6;
            
        case 'UplandSandyLoam'
            gamma=15.11e3;        c=3.3e3;          phi=0.588;      n=0.97;  kc=65.5e3;         kphi=1418e3;           Kt=0.093;     Kr=0.835; ShearType=3;

% clayed soil: p.214   
% sand: p.447
% loam: p.447
% max stress coefficients: p.386, also [4] p.3
            
%         case 'SoftSoil' %%% p.437 (density unknown)
%             gamma=0;              c=3.71e3;         phi=0.447;      n=0.8;   kc=16.5e3;         kphi=911e3;            Kt=0.021;     Kr=1;     ShearType=1;
            
%         case 'MediumSoil2' %%% p.355 (density unknown)
%             gamma=0;              c=6.89e3;         phi=0.506;      n=0.8;   kc=16.54e3;        kphi=911.4e3;          Kt=0.025;     Kr=1;     ShearType=1;
    

        otherwise
            disp('invalid terrain'); 
    end

    Terrain.gamma = gamma;
    Terrain.c = c;
    Terrain.phi = phi;
    Terrain.n = n;
    Terrain.kc = kc;
    Terrain.kphi = kphi;
    Terrain.Kt = Kt;
    Terrain.Kr = Kr;
    Terrain.ShearType = ShearType;
    
    Terrain.a0 = a0;
    Terrain.a1 = a1;
    Terrain.b0 = b0;
    Terrain.b1 = b1;
    
    Terrain.k0 = k0;
    Terrain.Au = Au;

end
